pub fn with_decoding_context<T>(
result: Result<T, DecodeError>,
context: &'static str,
) -> Result<T, DecodeError>Expand description
Adds schema context to an error returned while decoding a field.
pub fn with_decoding_context<T>(
result: Result<T, DecodeError>,
context: &'static str,
) -> Result<T, DecodeError>Adds schema context to an error returned while decoding a field.